@@ -160,13 +160,17 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
+    "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
+    "Are you sure you want to proceed?" : "您想要繼續嗎？",
     "Search contacts …" : "搜尋聯絡人……",
+    "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group}",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
     "Search for people to add" : "搜尋要新增的人",
-    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
     "No results" : "沒有結果",
     "Add {type}" : "新增 {type}",
     "New team name" : "新團隊名稱",
